summaryrefslogtreecommitdiffstats
path: root/chrome/browser/gears_integration.h
diff options
context:
space:
mode:
authorjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-02-17 23:32:51 +0000
committerjhawkins@chromium.org <jhawkins@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-02-17 23:32:51 +0000
commit4e5c1084d36e100572b2bcee0c10caf35e0f2367 (patch)
tree2b1b80512adcbbf1c7552cf4c25d8905cbd13326 /chrome/browser/gears_integration.h
parent0cbd2d367068d9b5cc00cf39238f0277cef5ba15 (diff)
downloadchromium_src-4e5c1084d36e100572b2bcee0c10caf35e0f2367.zip
chromium_src-4e5c1084d36e100572b2bcee0c10caf35e0f2367.tar.gz
chromium_src-4e5c1084d36e100572b2bcee0c10caf35e0f2367.tar.bz2
Make gears_integration.cc compile on Posix. Change the GearsCreateShortcut callback to use GearsShortCutData2.
Review URL: http://codereview.chromium.org/20412 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@9918 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/gears_integration.h')
-rw-r--r--chrome/browser/gears_integration.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/chrome/browser/gears_integration.h b/chrome/browser/gears_integration.h
index 708b43d..f6832ba 100644
--- a/chrome/browser/gears_integration.h
+++ b/chrome/browser/gears_integration.h
@@ -7,6 +7,7 @@
#include <string>
+#include "base/gfx/native_widget_types.h"
#include "base/task.h"
#include "chrome/common/gears_api.h"
@@ -27,16 +28,16 @@ struct GearsCreateShortcutData : public GearsShortcutData2 {
CPCommandInterface* command_interface;
};
// Called when the Gears Settings button is pressed. |parent_hwnd| is the
// window the Gears Settings dialog should be parented to.
-void GearsSettingsPressed(HWND parent_hwnd);
+void GearsSettingsPressed(gfx::NativeWindow parent_wnd);
// Calls into the Gears API to create a shortcut with the given parameters.
// 'app_info' is the optional information provided by the page. If any info is
// missing, we fallback to the given fallback params. 'fallback_icon' must be a
// 16x16 favicon. 'callback' will be called with a value indicating whether the
// shortcut has been created successfully.
-typedef Callback2<const GearsShortcutData&, bool>::Type
+typedef Callback2<const GearsShortcutData2&, bool>::Type
GearsCreateShortcutCallback;
void GearsCreateShortcut(
@@ -27,16 +28,16 @@ struct GearsCreateShortcutData : public GearsShortcutData2 {
CPCommandInterface* command_interface;
};
-// Called when the Gears Settings button is pressed. |parent_hwnd| is the
+// Called when the Gears Settings button is pressed. |parent_wnd| is the
// window the Gears Settings dialog should be parented to.